import { HttpError } from './http-error';
import { Application, ErrorHandler as ErrorHandlerContract, HttpContext, Logger, ViewEngine } from '@supercharge/contracts';
export declare class ErrorHandler implements ErrorHandlerContract {
    /**
     * The application instance.
     */
    protected readonly app: Application;
    /**
     * The list of error types to not report.
     */
    protected readonly ignoredErrors: ErrorConstructor[];
    /**
     * Stores the list of report callbacks.
     */
    protected readonly reportCallbacks: Array<(ctx: HttpContext, error: HttpError) => void | Promise<void>>;
    /**
     * Create a new error handler instance.
     */
    constructor(app: Application);
    /**
     * The application’s logger instance.
     */
    logger(): Logger;
    /**
     * The application’s view renderer.
     */
    view(): ViewEngine;
    /**
     * Register the error handling callbacks. For example, to report error
     * upstream to an error tracking service, like Sentry or Bugsnag.
     */
    register(): void;
    /**
     * Tell the error handler to not report the `error` type.
     */
    ignore(error: ErrorConstructor): this;
    /**
     * Returns an array of errors that should not be reported.
     */
    dontReport(): ErrorConstructor[];
    /**
     * Determine whether to report the given `error`.
     */
    shouldntReport(error: any): boolean;
    /**
     * Register a reportable callback.
     *
     * @param  {Function} reportUsing
     *
     * @returns {ErrorHandler}
     */
    reportable(reportUsing: (ctx: HttpContext, error: any) => void | Promise<void>): ErrorHandler;
    /**
     * Returns the error’s context for logging.
     *
     * @param {*}error
     *
     * @returns {Record<string, any>}
     */
    errorContext(error: any): Record<string, any>;
    /**
     * Returns the default logging context.
     *
     * @param {HttpContext} ctx
     *
     * @returns {*}
     */
    context(_ctx: HttpContext): any;
    /**
     * Handle the given error.
     *
     * @param {HttpContext} ctx
     * @param {Error} error
     */
    handle(ctx: HttpContext, error: any): Promise<void>;
    /**
     * Report an error.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    report(ctx: HttpContext, error: any): Promise<void>;
    /**
     * Determine whether the given `error` is implementing a `handle` method and
     * that `handle` method returns a truthy value, like a valid HTTP response.
     *
     * @param {HttpContext} ctx
     * @param {Error} error
     *
     * @returns {*}
     */
    errorReported(ctx: HttpContext, error: any): Promise<unknown>;
    /**
     * Render the error into an HTTP response.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    render(ctx: HttpContext, error: any): Promise<any>;
    /**
     * Determine whether the given `error` is implementing a `render` method and
     * that `render` method returns a truthy value, like a valid HTTP response.
     *
     * @param {HttpContext} ctx
     * @param {Error} error
     *
     * @returns {*}
     */
    errorRendered(ctx: HttpContext, error: any): Promise<unknown>;
    /**
     * Creates a JSON response depending on the app’s environment.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    protected renderJsonResponse(ctx: HttpContext, error: HttpError): void;
    /**
     * Creates an HTML response depending on the app’s environment.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    protected renderViewResponse(ctx: HttpContext, error: HttpError): Promise<void>;
    /**
     * Determine whether a view template file is missing for the given `error`.
     *
     * @param {HttpError} error
     *
     * @returns {Boolean}
     */
    protected isMissingTemplateFor(error: HttpError): Promise<boolean>;
    /**
     * Determine whether a view template file exists for the given `error`.
     *
     * @param {HttpError} error
     *
     * @returns {Boolean}
     */
    protected templateExistsFor(error: HttpError): Promise<boolean>;
    /**
     * Returns the view template file for the given `error`.
     *
     * @param {HttpError} error
     *
     * @returns {String}
     */
    protected viewTemplateFor(error: HttpError): string;
    /**
     * Renders an HTML response containing details about the given `error`.
     *
     * @param {HttpContext} ctx
     * @param {HttpError} error
     */
    renderYouchResponse({ request, response }: HttpContext, error: HttpError): Promise<void>;
}
